@@ -13,12 +13,12 @@ class WidgetWrapper(ABC):
     def widget(self):
         pass
 
-    @property
-    def required_modules(self) -> List[Type[Module]]:
+    @staticmethod
+    def required_modules() -> List[Type[Module]]:
         return []
 
     def display(self):
         """Should use this method to display the widget instead of directly displaying self.widget"""
-        for m in self.required_modules:
+        for m in self.required_modules():
             m.register()
         return display(self.widget)
